#
# spec file for package ghc-math-functions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name math-functions
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.4.4
Release:        1.9
Summary:        Collection of tools for numeric computations
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-data-default-class-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-primitive-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-erf-devel
BuildRequires:  ghc-erf-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
BuildRequires:  ghc-vector-th-unbox-devel
BuildRequires:  ghc-vector-th-unbox-prof
%endif

%description
This library contain collection of various utilities for numerical computing.
So far there're special mathematical functions, compensated summation
algorithm, summation of series, root finding for real functions, polynomial
summation and Chebyshev polynomials.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc README.markdown changelog.md doc

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Mar 30 2024 Peter Simons <psimons@suse.com>
- Update math-functions to version 0.3.4.4.
  [#]# Changes in 0.3.4.4
  * Support for future versions of GHC. Monoid and Monad instances now have
    canonical form
* Wed Oct 18 2023 Peter Simons <psimons@suse.com>
- Update math-functions to version 0.3.4.3.
  [#]# Changes in 0.3.4.3
  * Support for `QuickCheck >= 2.14`. Test no longer fail
  * Support for GHC<8.0 dropped
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Mar 29 2021 psimons@suse.com
- Update math-functions to version 0.3.4.2.
  [#]# Changes in 0.3.4.2
  * Fixed crash in `invIncompleteBeta` (#68) for some inputs initial approximation
    was computed incorrectly.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sat Aug 15 2020 psimons@suse.com
- Update math-functions to version 0.3.4.1.
  [#]# Changes in 0.3.4.1
  * Precision of `incompleteGamma` improved.
* Tue Jun  9 2020 psimons@suse.com
- Update math-functions to version 0.3.4.0.
  [#]# Changes in 0.3.4.0
  * Dependency on `vector-th-unbox` is dropped. All instances are written by
    hand now.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Wed Sep 25 2019 psimons@suse.com
- Update math-functions to version 0.3.3.0.
  [#]# Changes in 0.3.3.0
  * New implementation for `logGamma`. Now it's precise within 2 ulps at full
    range including zeros at 1 and 2.
  * Bug with precision loss of `invErf` for parameters near zero is fixed.
  * Fixed loss of precision in bundled `erf` near zero. (Affect primarily GHCJS)
  * `factorial` for now uses lookup table
  * `logFactorial` is optimized a bit (less number of terms is used)
  * `m_sqrt_eps` constant added.
  * Module `Numeric.SpecFunctions.Internal` is exposed.
  * Many improvements for test suite. Tables of expected function values are
    generated with mpmath, error estimates improved. Test suite itself is
    migrated to `tasty` from `test-framework`.
* Tue Sep 10 2019 psimons@suse.com
- Update math-functions to version 0.3.2.1.
  [#]# Changes in 0.3.2.1
  * Fixes build on windows for GHC<8.0
* Fri Sep  6 2019 psimons@suse.com
- Update math-functions to version 0.3.2.0.
  [#]# Changes in 0.3.2.0
  * GHCJS is now supported
  * Flag `system-expm1` is set to true by default. Only affects GHC<8.0
* Wed Nov 14 2018 psimons@suse.com
- Update math-functions to version 0.3.1.0.
  [#]# Changes in 0.3.1.0
  * Exported data types for iteration steps in root finding
  * Defaults for root finding algorithm are documented
* Thu Oct  4 2018 psimons@suse.com
- Update math-functions to version 0.3.0.2.
  [#]# Changes in 0.3.0.2
  * Fix license field in cabal file
* Fri Jul 20 2018 psimons@suse.com
- Add math-functions at version 0.3.0.1.
